@@ -1,35 +1,30 @@
 /*
     SDL - Simple DirectMedia Layer
-    Copyright (C) 1997, 1998, 1999, 2000, 2001  Sam Lantinga
+    Copyright (C) 1997-2009 Sam Lantinga
 
     This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
+    modify it under the terms of the GNU Lesser General Public
     License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+    version 2.1 of the License, or (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+    Lesser General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public
-    License along with this library; if not, write to the Free
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
     Sam Lantinga
-    slouken@devolution.com
+    slouken@libsdl.org
 */
-
-#ifdef SAVE_RCSID
-static char rcsid =
- "@(#) $Id: SDL_syssem.c,v 1.2 2001/04/26 16:50:18 hercules Exp $";
-#endif
+#include "SDL_config.h"
 
 /* Semaphores in the BeOS environment */
 
 #include <be/kernel/OS.h>
 
-#include "SDL_error.h"
 #include "SDL_thread.h"
 
 
@@ -42,12 +37,12 @@ SDL_sem *SDL_CreateSemaphore(Uint32 initial_value)
 {
 	SDL_sem *sem;
 
-	sem = (SDL_sem *)malloc(sizeof(*sem));
+	sem = (SDL_sem *)SDL_malloc(sizeof(*sem));
 	if ( sem ) {
 		sem->id = create_sem(initial_value, "SDL semaphore");
 		if ( sem->id < B_NO_ERROR ) {
 			SDL_SetError("create_sem() failed");
-			free(sem);
+			SDL_free(sem);
 			sem = NULL;
 		}
 	} else {
@@ -63,7 +58,7 @@ void SDL_DestroySemaphore(SDL_sem *sem)
 		if ( sem->id >= B_NO_ERROR ) {
 			delete_sem(sem->id);
 		}
-		free(sem);
+		SDL_free(sem);
 	}
 }
 
@@ -90,6 +85,12 @@ int SDL_SemWaitTimeout(SDL_sem *sem, Uint32 timeout)
 	    case B_NO_ERROR:
 		retval = 0;
 		break;
+	    case B_TIMED_OUT:
+		retval = SDL_MUTEX_TIMEDOUT;
+		break;
+	    case B_WOULD_BLOCK:
+		retval = SDL_MUTEX_TIMEDOUT;
+		break;
 	    default:
 		SDL_SetError("acquire_sem() failed");
 		retval = -1;
